@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Error;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Error::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.5_1');
+use version; our $VERSION = qv('v0.10.1');
 
 use Moose;
 use Carp qw( cluck );
@@ -217,7 +217,7 @@ B<Returns:> Nothing (string is cleared)
 
 =over
 
-L<github Spreadsheet-XLSX-Reader-LibXML/issues|https://github.com/jandrew/Spreadsheet-XLSX-Reader-LibXML/issues>
+L<github Spreadsheet::XLSX::Reader::LibXML/issues|https://github.com/jandrew/Spreadsheet-XLSX-Reader-LibXML/issues>
 
 =back
 
@@ -275,6 +275,8 @@ L<Spreadsheet::XLSX::Reader::LibXML::LogSpace>
 
 L<Spreadsheet::XLSX>
 
+L<Spreadsheet::ParseXLSX>
+
 L<Log::Shiras|https://github.com/jandrew/Log-Shiras>
 
 =back
