@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::GetCell;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::GetCell::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.5_1');
+use version; our $VERSION = qv('v0.10.1');
 
 use	Moose::Role;
 requires qw(
@@ -492,196 +492,7 @@ Spreadsheet::XLSX::Reader::LibXML::GetCell - Top level xlsx worksheet interface
     
 =head1 DESCRIPTION
 
-This is a fairly simple implementation of a regex and math to find the column and row
-position in excel from an 'A1' style Excel cell ID.  It is important to note that column 
-letters do not equal digits in a modern 26 position numeral system since the excel 
-implementation is effectivly zeroless.
-
-The default of this module, however, is to count from zero.  Meaning that cell A1 is 
-equal to (0, 0).  See the L<Attributes|/Attributes> and L<Methods|/Methods> section for 
-ways to change this behaviour.
-
-=head1 SYNOPSIS
-	
-	#!perl
-	package MyPackage;
-	use Moose;
-	with 'Spreadsheet::XLSX::Reader::LibXML::CellToColumnRow';
-
-	sub set_error{}
-	sub get_log_space{}
-		
-	sub my_method{
-		my ( $self, $cell ) = @_;
-		my ($column, $row ) = $self->parse_column_row( $cell );
-		print $self->error if( !defined $column or !defined $row );
-		return ($column, $row );
-	}
-
-	package main;
-
-	my $parser = MyPackage->new( count_from_zero => 0 );
-	print '(' . join( ', ', $parser->my_method( 'B2' ) ) . ")'\n";
-	
-	###########################
-	# SYNOPSIS Screen Output
-	# 01: (2, 2)
-	###########################
-	
-=head2 Attributes
-
-Attiributes are ways to change the instances behaviour and can be set as arguments 
-to -E<gt>new
-
-=head3 count_from_zero
-
-=over
-
-B<Definition:> A boolean attribute that determines if the numerical output of 
-L<parse_column_row|/parse_column_row( $excel_row_id )> provides a response counting from 
-Zero or One. True = count from Zero.
-
-B<Accepts:> $bool = (1|0)
-
-=back
-	
-=head2 Methods
-
-Methods are object methods (not functional methods)
-
-=head3 parse_column_row( $excel_row_id, $count_from_one )
-
-=over
-
-B<Definition:> This is the way to turn an alpha numeric Excel cell ID into row and column 
-integers.  If count_from_zero = 1 but you want (column, row) pairs returned counting from 
-1 then set $count_from_one = 1.  Or leave it blank to have the pair returned in the format 
-defined by L<count_from_zero|/count_from_zero>
-
-B<Accepts:> $excel_row_id, $count_from_one
-
-B<Returns:> ( $column_number, $row_number ) - integers
-
-=back
-
-=head3 build_cell_label( $column, $row, $count_from_one )
-
-=over
-
-B<Definition:> This is the way to turn a (column, row) pair into an excel ID.  If 
-$count_from_one is set then the ($column, $row pair will be treated at counting from one 
-independant of how L<count_from_zero|/count_from_zero> is set.
-integers
-
-B<Accepts:> $column, $row, $count_from_one (in that order and position)
-
-B<Returns:> ( $excel_cell_id ) - integers
-
-=back
-
-=head3 counting_from_zero( $bool )
-
-=over
-
-B<Definition:> This turns on (or off) counting from zero where the alternative is to 
-count from 1.
-
-B<Accepts:> $bool = (1|0)
-
-B<Returns:> nothing
-
-=back
-
-=head3 get_excel_position( $int )
-
-=over
-
-B<Definition:> If you wish to use this sheet agnostically of the L<count_from_zero|/count_from_zero> 
-setting then you can use this method to translate integers to a count-from-one number.  No action is 
-taken if the attribute is set to 0.
-
-B<Accepts:> a $count_from_one or a $count_from_zero int
-
-B<Returns:> a $count_from_one int
-
-=back
-
-=head3 get_used_position( $int )
-
-=over
-
-B<Definition:> If you wish to use this sheet agnostically of the L<count_from_zero|/count_from_zero> 
-setting then you can use this method to translate integers from a count-from-one number to whatever 
-scheme is in force from the attribute.  No action is taken if the attribute is set to 0.
-
-B<Accepts:> a $count_from_one int
-
-B<Returns:> a $count_from_one or a $count_from_zero int
-
-=back
-
-=head1 SUPPORT
-
-=over
-
-L<github Spreadsheet-XLSX-Reader-LibXML/issues|https://github.com/jandrew/Spreadsheet-XLSX-Reader-LibXML/issues>
-
-=back
-
-=head1 TODO
-
-=over
-
-B<1.> Nothing L<yet|/SUPPORT>
-
-=back
-
-=head1 AUTHOR
-
-=over
-
-=item Jed Lund
-
-=item jandrew@cpan.org
-
-=back
-
-=head1 COPYRIGHT
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
-This software is copyrighted (c) 2014 by Jed Lund
-
-=head1 DEPENDENCIES
-
-=over
-
-L<version>
-
-L<Moose::Role>
-
-L<Types::Standard>
-
-requires
-
-	name_space
-	set_error
-
-=back
-
-=head1 SEE ALSO
-
-=over
-
-L<Spreadsheet::XLSX>
-
-L<Log::Shiras|https://github.com/jandrew/Log-Shiras>
-
-=back
+POD not written yet!
 
 =cut
 
