@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.5_1');
+use version; our $VERSION = qv('v0.10.1');
 
 
 use	5.010;
@@ -631,7 +631,7 @@ __END__
 
 =head1 NAME
 
-Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet - A class for exploring XLSX worksheets
+Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet - A LibXML::Reader worksheet base class
 
 =head1 SYNOPSIS
 
@@ -639,389 +639,7 @@ See the SYNOPSIS in L<Spreadsheet::XLSX::Reader::LibXML>
     
 =head1 DESCRIPTION
 
-This is the class used to interrogate Excel xlsx worksheets for information.  Because 
-the Excel xlsx storage of information can be (but not always) spread across multiple xml 
-files this class is the way to retreive information about the sheet independant of which 
-file it is in.  This is the L<XMLReader|Spreadsheet::XLSX::Reader::LibXML::XMLReader> 
-version of this class.  Where possible this class makes the decision to read files by line 
-rather than parse the file using a DOM tree.  The up side to this is that large files will 
-(hopefully) not crash when opened and the data will available using the same methods.  
-The down side is that the file opens slower since the whole sheet is read twice before 
-information is available.  Additionally data is best accessed sequentially left to right 
-and top to bottom since going back will involve a system file close and re-open action.
-
-=head2 Attributes
-
-Attributes of this cell are not included in the documentation because 'new' should be 
-called by L<other|Spreadsheet::XLSX::Reader::LibXML> classes in this package.
-
-=head2 Methods
-
-These are ways to access the data and formats in the cell.  They also provide a 
-way to modifiy the output of the format.
-
-=head3 get_name
-
-=over
-
-B<Definition:> Returns the sheet name
-
-B<Accepts:>Nothing
-
-B<Returns:> $sheet_name
-
-=back
-
-=head3 row_range
-
-=over
-
-B<Definition:> Returns the minimum row number and the maximum row number based on the 
-settings of attribute 'count_from_zero' set when first creating the file parser with 
-L<Spreadsheet::XLSX::Reader::LibXML>.
-
-B<Accepts:>Nothing
-
-B<Returns:> a list of ( $minimum_row, $max_row )
-
-=back
-
-=head3 col_range
-
-=over
-
-B<Definition:> Returns the minimum column number and the maximum column number based on 
-the settings of attribute 'count_from_zero' set when first creating the file parser with 
-L<Spreadsheet::XLSX::Reader::LibXML>.
-
-B<Accepts:>Nothing
-
-B<Returns:> a list of ( $minimum_column, $max_column )
-
-=back
-
-=head3 get_cell( $row, $column )
-
-=over
-
-B<Definition:> Returns a L<Spreadsheet::XLSX::Reader::LibXML::Cell> instance corresponding 
-to the identified $row and $column.  The actual position returned are affected by the 
-attribute 'count_from_zero' set when first creating the file parser with 
-L<Spreadsheet::XLSX::Reader::LibXML>.  If there is no data stored in that cell it returns 
-undef.  If the $column selected is past the L<max_col|/max_col> value then it returns the 
-string 'EOR'.  If the $row selected is past the L<max_row|/max_row> value then it returns 
-the string 'EOF'.
-
-If both $row and $column are left blank this is effectivly a 'get_(next)_cell' command 
-moving left to right and top to bottom starting from either the last position identified 
-or the sheet minimum row and column.  When the end of the file is reached it returns the 
-string 'EOF';
-
-If only the $row is specified it will return the next cell in that $row starting from the 
-last column specified I<even if it was a different row> or starting from the minimum column.  
-When the row is finished it will return the string 'EOR' and reset the next column to be 
-the minimum column.  (The sheet starts with the minimum column as the next column on 
-opening.)  This implementation is pre-deprecated and will be removed when the 
-'fetchrow_arrayref' function is implemented.  That that point this method will require 
-either both $row and $column or neither.
-
-If only the $column is specified this will return undef and set the 
-L<error|Spreadsheet::XLSX::Reader::Error> message returning undef.  
-
-B<Accepts:> ( $row, $column ) - as indicated in the Definition
-
-B<Returns:> (undef|a blessed L<Spreadsheet::XLSX::Reader::LibXML::Cell> instance|'EOR'|'EOF')
-
-=back
-		
-=head3 set_warnings( $bool )
-
-=over
-
-B<Definition:> Turn clucked warnings on or off from L<Spreadsheet::XLSX::Reader::LibXML::Error>
-
-B<Accepts:> Boolean values
-
-B<Returns:> nothing
-
-=back
-		
-=head3 if_warn
-
-=over
-
-B<Definition:> Check the state of the boolean affected by L<set_warnings
-|/set_warnings( $bool )> attribute value from L<Spreadsheet::XLSX::Reader::LibXML::Error>
-
-B<Accepts:> Nothing
-
-B<Returns:> $bool
-
-=back
-		
-=head3 error
-
-=over
-
-B<Definition:> Returns the currently stored error string from 
-L<Spreadsheet::XLSX::Reader::LibXML::Error>
-
-B<Accepts:> Nothing
-
-B<Returns:> $error_string
-
-=back
-
-=head3 clear_error
-
-=over
-
-B<Definition:> method to clear the current error string from 
-L<Spreadsheet::XLSX::Reader::LibXML::Error>
-
-B<Accepts:> Nothing
-
-B<Returns:> Nothing (string is cleared)
-
-=back
-
-=head3 min_col
-
-=over
-
-B<Definition:> method to read the minimum column for the sheet
-
-B<Accepts:> Nothing
-
-B<Returns:> $minimum_column (Integer)
-
-=back
-
-=head3 has_min_col
-
-=over
-
-B<Definition:> indicates if a minimum column has been determined
-
-B<Accepts:> Nothing
-
-B<Returns:> $bool TRUE = exists
-
-=back
-
-=head3 min_row
-
-=over
-
-B<Definition:> method to read the minimum row for the sheet
-
-B<Accepts:> Nothing
-
-B<Returns:> $minimum_row (Integer)
-
-=back
-
-=head3 has_min_row
-
-=over
-
-B<Definition:> indicates if a minimum row has been determined
-
-B<Accepts:> Nothing
-
-B<Returns:> $bool TRUE = exists
-
-=back
-
-=head3 max_col
-
-=over
-
-B<Definition:> method to read the maximum column for the sheet
-
-B<Accepts:> Nothing
-
-B<Returns:> $maximum_column (Integer)
-
-=back
-
-=head3 has_max_col
-
-=over
-
-B<Definition:> indicates if a maximum column has been determaxed
-
-B<Accepts:> Nothing
-
-B<Returns:> $bool TRUE = exists
-
-=back
-
-=head3 max_row
-
-=over
-
-B<Definition:> method to read the maximum row for the sheet
-
-B<Accepts:> Nothing
-
-B<Returns:> $maximum_row (Integer)
-
-=back
-
-=head3 has_max_row
-
-=over
-
-B<Definition:> indicates if a maximum row has been determaxed
-
-B<Accepts:> Nothing
-
-B<Returns:> $bool TRUE = exists
-
-=back
-
-=head3 set_custom_formats( $hashref )
-
-=over
-
-B<Definition:> It is not inconceivable that the module user would need/want the data 
-manipulated in some way that was not provided natively by excel.  This package uses 
-the excellent L<Type::Tiny> to implement the default data manipulations identified 
-by the spreadsheet.  However, it is possible for the user to supply a hashref of 
-custom data manipulations.  The hashref is read where the key is a row-column 
-indicator and the value is a data manipulation coderef/object that has (at least) 
-the following two methods.  The first method is 'coerce' and the second method is 
-'display_name'.  For each cell instance generated the L<get_cell
-|/get_cell( $row, $column)> method will check the cell_id (ex. B34) for matches in this 
-hashref and then if none are found it will apply any format(data manipulation) defined 
-in the spreadsheet. For a match on any given cell checks will be done in this order; 
-full cell_id (ex. B34), column_id (ex. B), row_id (ex.34)
-
-B<Accepts:> a $hashref (ex. { B34 => MyTypeTinyType->plus_coercions( MyCoercion ) } )
-
-B<Returns:> Nothing
-
-=back
-
-=head3 set_custom_format( $key => $value_ref )
-
-=over
-
-B<Definition:> The difference with this method from L<set_custom_formats
-|/set_custom_formats( $hashref )> is this will only set specific key value pairs.
-
-B<Accepts:> a $key => $value_ref list
-
-B<Returns:> Nothing
-
-=back
-
-=head3 get_custom_format( $key )
-
-=over
-
-B<Definition:> This returns the custom format associated with that key
-
-B<Accepts:> a $key
-
-B<Returns:> The $value_ref (data manipulation ref) associated with $key
-
-=back
-
-=head3 has_custom_format( $key )
-
-=over
-
-B<Definition:> This checks if a custom format is registered against the $key
-
-B<Accepts:> a $key
-
-B<Returns:> $boolean representing existance
-
-=back
-				
-=head1 SUPPORT
-
-=over
-
-L<github Spreadsheet::XLSX::Reader/issues|https://github.com/jandrew/Spreadsheet-XLSX-Reader/issues>
-
-=back
-
-=head1 TODO
-
-=over
-
-B<1.> Add min to max next cell
-
-B<2.> Add read Non-Null only next cells
-
-B<2.> Add 'fetchrow_arrayref( $row )' (as a Role?)
-
-B<3.> Add 'set_header_row( $row )' and 'fetchrow_hashref( $row )' (as a Role?)
-
-B<4.> Add L<Data::Walk::Graft> capabilities to 'set_custom_formats'
-
-B<5.> Move 'get_cell( $row, $column )' into a role?
-
-=back
-
-=head1 AUTHOR
-
-=over
-
-=item Jed Lund
-
-=item jandrew@cpan.org
-
-=back
-
-=head1 COPYRIGHT
-
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
-
-This software is copyrighted (c) 2014 by Jed Lund
-
-=head1 DEPENDENCIES
-
-=over
-
-B<5.010> - (L<perl>)
-
-L<version>
-
-L<Moose>
-
-L<MooseX::StrictConstructor>
-
-L<MooseX::HasDefaults::RO>
-
-L<Types::Standard>
-
-L<Spreadsheet::XLSX::Reader::LibXML::XMLReader>
-
-L<Spreadsheet::XLSX::Reader::LibXML::CellToColumnRow>
-
-L<Spreadsheet::XLSX::Reader::LibXML::Cell>
-
-=back
-
-=head1 SEE ALSO
-
-=over
-
-L<Spreadsheet::XLSX>
-
-L<Spreadsheet::ParseExcel::Worksheet>
-
-L<Log::Shiras|https://github.com/jandrew/Log-Shiras> - to activate the debug logging
-
-=back
+POD not written yet!
 
 =cut
 
